@@ -1,22 +1,19 @@
 from pathlib import Path
 from shutil import copyfile
-from typing import Optional
 
-from git import Repo
-from git.exc import InvalidGitRepositoryError
+from pygit2 import discover_repository, Repository
 
 from deckz.exceptions import DeckzException
 
 
-def get_git_dir(path: Path) -> Optional[Path]:
-    try:
-        repository = Repo(str(path), search_parent_directories=True)
-    except InvalidGitRepositoryError as e:
+def get_git_dir(path: Path) -> Path:
+    repository = discover_repository(str(path))
+    if repository is None:
         raise DeckzException(
             "Could not find the path of the current git working directory. "
             "Are you in one?"
-        ) from e
-    return Path(repository.git.rev_parse("--show-toplevel")).resolve()
+        )
+    return Path(Repository(repository).workdir).resolve()
 
 
 def copy_file_if_newer(original: Path, copy: Path) -> None:
